@@ -1,9 +1,37 @@
-/*
- * $Id: bitmap.h,v 1.10 1997/03/09 23:49:43 drd Exp $
+/* $Id: bitmap.h,v 1.1.1.2.2.1 1999/09/29 13:48:16 lhecking Exp $ */
+
+/* GNUPLOT - bitmap.h */
+
+/*[
+ * Copyright 1986 - 1993, 1998   Thomas Williams, Colin Kelley
  *
- */
+ * Permission to use, copy, and distribute this software and its
+ * documentation for any purpose with or without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear
+ * in supporting documentation.
+ *
+ * Permission to modify the software is granted, but not the right to
+ * distribute the complete modified source code.  Modifications are to
+ * be distributed as patches to the released version.  Permission to
+ * distribute binaries produced by compiling modified sources is granted,
+ * provided you
+ *   1. distribute the corresponding source modifications from the
+ *    released version in the form of a patch file along with the binaries,
+ *   2. add special version identification to distinguish your version
+ *    in addition to the base release version number,
+ *   3. provide your name and address as the primary contact for the
+ *    support of your modified version, and
+ *   4. retain our contact information in regard to use of the base
+ *    software.
+ * Permission to distribute the released version of the source code along
+ * with corresponding source modifications in the form of a patch file is
+ * granted with same provisions 2 through 4 for binary distributions.
+ *
+ * This software is provided "as is" without express or implied warranty
+ * to the extent permitted by applicable law.
+]*/
 
-/* bitmap.h */
 
 /* allow up to 16 bit width for character array */
 typedef unsigned int char_row;
@@ -54,6 +82,19 @@ extern unsigned int b_pattern[];
 extern int b_maskcount;
 extern unsigned int b_lastx, b_lasty;	/* last pixel set - used by b_line */
 
+/* RGB colour table moved out of gif.trm */
+/*
+ * Common RGB color table for use by all devices.
+ * It's a subset of the 216-color Web palette.
+ */
+#define WEB_N_COLORS 99
+struct rgb
+{
+    unsigned char r, g, b;
+};
+
+extern struct rgb web_color_rgbs[];
+
 
 /* Prototypes from file "bitmap.c" */
 
